@@ -29,6 +29,18 @@
 /* define SYS5  1 */
 /* define SVR4  1 */
 
+/*
+ * OSF/1
+ */
+/* #define SYS5  1 */
+/* #define SVR4  1 */
+
+/*
+ * HP-UX
+ */
+/* #define SYS5  1 */
+/* #define SVR4  1 */
+
 /*
  * Linux
  */
@@ -123,12 +135,6 @@
  */
 #define WAITINT 1
 
-/*
- * Define if you have socket support.  I'm assuming
- * everyone has this these days.
- */
-#define SOCKETS 1
-
 /***** END USER CONFIGURATION SECTION *****/
 @TOP@
 
