@@ -38,15 +38,15 @@ struct mailname {
 /*
  *  prototypes
  */
-void mnfree();
-int ismymbox();
-char *getname();
-char *adrsprintf();
-char *auxformat();
-struct mailname *getm();
+void mnfree(struct mailname *);
+int ismymbox(struct mailname *);
+char *getname(char *);
+char *adrsprintf(char *, char *);
+char *auxformat(struct mailname *, int);
+struct mailname *getm(char *, char *, int, int, char *);
 
-char *LocalName();
-char *SystemName();
-char *UucpChan();
-char *OfficialName();
+char *LocalName(void);
+char *SystemName(void);
+char *UucpChan(void);
+char *OfficialName(char *);
 
