@@ -32,10 +32,10 @@ struct comp {
 /*
  * c_type bits
  */
-#define	CT_ADDR		1	/* referenced as address    */
-#define	CT_DATE		2	/* referenced as date       */
-#define	CT_MYMBOX	4	/* "mymbox" test being done */
-#define	CT_ADDRPARSE	8	/* address parse being done */
+#define	CT_ADDR       (1<<0)	/* referenced as address    */
+#define	CT_DATE       (1<<1)	/* referenced as date       */
+#define	CT_MYMBOX     (1<<2)	/* "mymbox" test being done */
+#define	CT_ADDRPARSE  (1<<3)	/* address parse being done */
 
 extern int fmt_norm;
 
