@@ -174,17 +174,15 @@ typedef struct _iobuf *FP;
  * miscellaneous macros
  */
 #define	pidXwait(id,cp)	pidstatus (pidwait (id, NOTOK), stdout, cp)
-#define	setsig(s,f) if (signal (s, SIG_IGN) != SIG_IGN) { signal (s, f); }
-#define	setsigx(i,s,f)	if ((i = signal (s, SIG_IGN)) != SIG_IGN) { signal (s, f); }
 #define min(a,b) ((a) < (b) ? (a) : (b))
 #define abs(a) ((a) > 0 ? (a) : -(a))
 
 /*
  * GLOBAL VARIABLES
  */
-extern char ctxflags;
 #define CTXMOD	0x01		/* context information modified */
 #define	DBITS	"\020\01CTXMOD"
+extern char ctxflags;
 
 #ifdef	OVERHEAD
 extern int fd_def;
