@@ -5,6 +5,9 @@
  * $Id$
  */
 
+/*  Use built-in ftp client in mhn */
+#define FTP 1
+
 #define	VRSN_FIELD	"MIME-Version"
 #define	VRSN_VALUE	"1.0"
 #define	XXX_FIELD_PRF	"Content-"
@@ -59,7 +62,3 @@
 #define	LPERMSG	632
 #define	CPERMSG	(LPERMSG * CPERLIN)
 
-#ifdef SOCKETS
-# define FTP
-#endif
-
