@@ -58,12 +58,24 @@
 # include <locale.h>
 #endif
 
+/* symbolic constants for lseek */
 #ifdef HAVE_LIMITS_H
 # include <limits.h>
 #endif
+#ifndef SEEK_SET
+# define SEEK_SET 0
+#endif
+#ifndef SEEK_CUR
+# define SEEK_CUR 1
+#endif
+#ifndef SEEK_END
+# define SEEK_END 2
+#endif
 
-/* we should be getting this value from pathconf(_PC_PATH_MAX) */
-/* but this is too much trouble                                */
+/*
+ * we should be getting this value from pathconf(_PC_PATH_MAX)
+ * but this is too much trouble
+ */
 #ifndef PATH_MAX
 # ifdef MAXPATHLEN
 #  define PATH_MAX MAXPATHLEN
@@ -73,8 +85,10 @@
 # endif
 #endif
 
-/* we should be getting this value from sysconf(_SC_OPEN_MAX) */
-/* but this is too much trouble                               */
+/*
+ * we should be getting this value from sysconf(_SC_OPEN_MAX)
+ * but this is too much trouble
+ */
 #ifndef OPEN_MAX
 # ifdef NOFILE
 #  define OPEN_MAX NOFILE
