@@ -17,15 +17,12 @@
  * RP_-style codes.
  */
 
-#ifdef BSD42
 /*
- * Under 4.2BSD, the alarm handing stuff for time-outs will NOT
- * work due to the way syscalls get restarted.  This really is
- * not crucial, since we expect SendMail to be well-behaved and
- * not hang on us.  The only time I've ever seen Sendmail hang
- * was with a bogus configuration file...
+ * On older 4.2BSD machines without the POSIX function `sigaction',
+ * the alarm handing stuff for time-outs will NOT work due to the way
+ * syscalls get restarted.  This is not really crucial, since SendMail
+ * is generally well-behaved in this area.
  */
-#endif
 
 #ifdef SENDMAILBUG
 /*
@@ -200,8 +197,8 @@ sm_init (char *client, char *server, int watch, int verbose,
 	    _exit (-1);		/* NOTREACHED */
 
 	default: 
-	    signal (SIGALRM, alrmser);
-	    signal (SIGPIPE, SIG_IGN);
+	    SIGNAL (SIGALRM, alrmser);
+	    SIGNAL (SIGPIPE, SIG_IGN);
 
 	    close (pdi[1]);
 	    close (pdo[0]);
@@ -312,8 +309,8 @@ all_done: ;
 	return sm_ierror ("unable to dup");
     }
 
-    signal (SIGALRM, alrmser);
-    signal (SIGPIPE, SIG_IGN);
+    SIGNAL (SIGALRM, alrmser);
+    SIGNAL (SIGPIPE, SIG_IGN);
 
     if ((sm_rfp = fdopen (sd1, "r")) == NULL
 	    || (sm_wfp = fdopen (sd2, "w")) == NULL) {
@@ -1216,7 +1213,7 @@ again: ;
 	    if (doingEHLO == 2) {
 		int	len = strlen (buffer + 4);
 
-		if (*ehlo = malloc ((unsigned) (strlen (buffer + 4) + 1))) {
+		if ((*ehlo = malloc ((unsigned) (strlen (buffer + 4) + 1)))) {
 		    strcpy (*ehlo++, buffer + 4);
 		    *ehlo = NULL;
 		    if (ehlo >= EHLOkeys + MAXEHLO)
@@ -1331,11 +1328,11 @@ sm_rerror (void)
 static RETSIGTYPE
 alrmser (int i)
 {
-#ifndef	BSD42
-    signal (SIGALRM, alrmser);
-#endif	/* BSD42 */
-    sm_alarmed++;
+#ifndef	RELIABLE_SIGNALS
+    SIGNAL (SIGALRM, alrmser);
+#endif
 
+    sm_alarmed++;
     if (sm_debug) {
 	printf ("timed out...\n");
 	fflush (stdout);
