@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #ifdef HAVE_TERMIOS_H
 # include <termios.h>
