@@ -125,7 +125,7 @@ match (char *str, char *sub)
 	    return 1;
     }
 #else
-    while (c1 = *sub) {
+    while ((c1 = *sub)) {
 	while ((c2 = *str++) && (c1 | 040) != (c2 | 040))
 	    ;
 	if (! c2)
@@ -830,7 +830,7 @@ fmtscan (struct format *format, char *scanl, int width, int *dat)
 		(mn = getm (sp, NULL, 0, AD_NAME, NULL))) {
 		comp->c_mn = mn;
 		comp->c_flags = ismymbox(mn);
-		while (sp = getname(sp))
+		while ((sp = getname(sp)))
 		    if (comp->c_flags == 0 &&
 			(mn = getm (sp, NULL, 0, AD_NAME, NULL)))
 			comp->c_flags |= ismymbox(mn);
