@@ -155,7 +155,7 @@ not_open: ;
 	return fp;
     }
 
-    lseek (fd, (off_t)0, 0);
+    lseek (fd, (off_t)0, SEEK_SET);
     return fdopen (fd, mode);
 }
 
