@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 char *
@@ -16,7 +16,7 @@ m_seq(struct msgs *mp, char *cp)
 	register char *bp;
 	static char buffer[BUFSIZ*2];	/* for big sequences */
 
-	if (strcmp (current, cp) == 0) {
+	if (!strcmp (current, cp)) {
 	    /* assume this is in sync with msgstats["cur"] */
 	    /* see m_seqadd() for details */
 	    if (mp->curmsg) {	
@@ -26,10 +26,10 @@ m_seq(struct msgs *mp, char *cp)
 		return (NULL);
 	}
 	for (i = 0; mp->msgattrs[i]; i++)
-		if (strcmp(mp->msgattrs[i], cp) == 0)
+		if (!strcmp(mp->msgattrs[i], cp))
 			break;
 	
-	if (! mp->msgattrs[i])
+	if (!mp->msgattrs[i])
 		return (NULL);
 
 	mask = EXISTS | (1 << (FFATTRSLOT + i));
