@@ -5,20 +5,18 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 void
 m_setcur (struct msgs *mp, int num)
 {
-    int bits, public;
-    register int i;
+    int i, public;
 
-    public = mp->msgflags & READONLY ? 0 : 1;
-    bits = FFATTRSLOT;
+    public = !(mp->msgflags & READONLY);
     for (i = 0; mp->msgattrs[i]; i++)
-	if (strcmp (mp->msgattrs[i], current) == 0) {
-	    public = mp->attrstats & (1 << (bits + i)) ? 0 : 1;
+	if (!strcmp (mp->msgattrs[i], current)) {
+	    public = !(mp->attrstats & (1 << (FFATTRSLOT + i)));
 	    break;
 	}
 
