@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
+#include <h/mh.h>
+#include <h/signals.h>
 
 
 /*
@@ -44,16 +44,16 @@ m_sync (struct msgs *mp)
 	if (mp->msgflags & READONLY
 		|| mp->attrstats & (1 << (bits + i))) {
     priv: ;
-	    if (cp = m_seq (mp, mp->msgattrs[i]))
+	    if ((cp = m_seq(mp, mp->msgattrs[i])))
 		m_replace (attr, cp);
 	    else
 		m_delete (attr);
 	}
 	else {
 	    m_delete (attr);
-	    if ((cp = m_seq (mp, mp->msgattrs[i])) == NULL)
+	    if (!(cp = m_seq(mp, mp->msgattrs[i])))
 		continue;
-	    if (fp == NULL) {
+	    if (!fp) {
 		if ((fp = fopen (seq, "w")) == NULL
 			&& (unlink (seq) == NOTOK ||
 			    (fp = fopen (seq, "w")) == NULL)) {
