@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
+#include <h/mh.h>
+#include <h/signals.h>
 
 /*
  * static prototypes
@@ -19,7 +19,7 @@ m_update(void)
 {
     int action;
     register struct node *np;
-    FILE * out;
+    FILE *out;
     sigset_t set, oset;
 
     if (!(ctxflags & CTXMOD))
@@ -37,7 +37,7 @@ m_update(void)
     sigaddset (&set, SIGTERM);
     SIGPROCMASK (SIG_BLOCK, &set, &oset);
 
-    if ((out = fopen (ctxpath, "w")) == NULL)
+    if (!(out = fopen (ctxpath, "w")))
 	adios (ctxpath, "unable to write");
     for (np = m_defs; np; np = np->n_next)
 	if (np->n_context)
