@@ -5,20 +5,14 @@
  * $Id$
  */
 
-/* Modified to try recursive create.  Really, this should be broken
- * out into a subr so that SYS5 systems can do this too.  I don't 
- * have a SYS5 machine around to test anymore, so someone else will
- * have to send me the code.
+/*
+ * Modified to try recursive create.
  */
 
 #include <h/mh.h>
-
-#if defined (BSD42) || defined (hpux) || defined(SVR4) || \
-	defined(ncr) || defined (_AIX) || defined(AUX)
-# include <errno.h>
-# include <sys/param.h>
-# include <sys/file.h>
-#endif /* BSD42 ... */
+#include <errno.h>
+#include <sys/param.h>
+#include <sys/file.h>
 
 extern int errno;
 	
