@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <h/signals.h>
 #include <signal.h>
 
 
@@ -21,14 +22,14 @@ push(void)
 		continue;
 
 	    case OK: 
-		signal (SIGHUP, SIG_IGN);
-		signal (SIGINT, SIG_IGN);
-		signal (SIGQUIT, SIG_IGN);
-		signal (SIGTERM, SIG_IGN);
+		SIGNAL (SIGHUP, SIG_IGN);
+		SIGNAL (SIGINT, SIG_IGN);
+		SIGNAL (SIGQUIT, SIG_IGN);
+		SIGNAL (SIGTERM, SIG_IGN);
 #ifdef SIGTSTP
-		signal (SIGTSTP, SIG_IGN);
-		signal (SIGTTIN, SIG_IGN);
-		signal (SIGTTOU, SIG_IGN);
+		SIGNAL (SIGTSTP, SIG_IGN);
+		SIGNAL (SIGTTIN, SIG_IGN);
+		SIGNAL (SIGTTOU, SIG_IGN);
 #endif	/* SIGTSTP */
 		freopen ("/dev/null", "r", stdin);
 		freopen ("/dev/null", "w", stdout);
@@ -42,3 +43,4 @@ push(void)
     if (i >= 5)
 	advise (NULL, "unable to fork, so can't push...");
 }
+
