@@ -123,7 +123,8 @@ main (int argc, char **argv)
     }
 
     if (!noalias) {
-	if (cp = m_find ("Aliasfile")) { /* allow Aliasfile: profile entry */
+	/* allow Aliasfile: profile entry */
+	if ((cp = m_find ("Aliasfile"))) {
 	    char *dp = NULL;
 
 	    for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++)
@@ -167,7 +168,7 @@ print_aka (char *p, int list, int margin)
 	return;
     }
 
-    while (c = *p++)
+    while ((c = *p++))
 	switch (c) {
 	    case ',': 
 		if (*p)
@@ -212,7 +213,7 @@ print_usr (char *s, int list, int norm)
     vp = NULL;
     for (ak = akahead; ak; ak = ak->ak_next) {
 	pp = akresult (ak);
-	while (cp = getname (pp)) {
+	while ((cp = getname (pp))) {
 	    if ((np = getm (cp, NULL, 0, norm, NULL)) == NULL)
 		continue;
 	    if (uleq (mp->m_host, np->m_host)
