@@ -81,7 +81,7 @@ annosbr (int src, char *file, char *comp, char *text, int inplace, int datesw)
     if (inplace) {
 	if ((fd = open (tmpfil, 0)) == NOTOK)
 	    adios (tmpfil, "unable to open for re-reading");
-	lseek (src, (off_t) 0, 0);
+	lseek (src, (off_t) 0, SEEK_SET);
 	cpydata (fd, src, tmpfil, file);
 	close (fd);
 	unlink (tmpfil);
