@@ -161,7 +161,7 @@ process (char *arg, int length, int norm)
     register struct mailname *mp;
 
     (q = &pq)->pq_next = NULL;
-    while (cp = getname (arg)) {
+    while ((cp = getname (arg))) {
 	if ((p = (struct pqpair *) calloc ((unsigned) 1, sizeof *p)) == NULL)
 	    adios (NULL, "unable to allocate pqpair memory");
 	if ((mp = getm (cp, NULL, 0, norm, error)) == NULL) {
