@@ -19,7 +19,7 @@
 
 #include <errno.h>
 
-#if defined(SOCKETS) && defined(NTOHLSWAP)
+#ifdef NTOHLSWAP
 # include <netinet/in.h>
 #else
 # define ntohl(n) (n)
@@ -78,7 +78,7 @@ mbx_open (char *file, uid_t uid, gid_t gid, mode_t mode)
 		break;
 
 	    case UUCP: 
-		if (lseek (fd, (off_t) 0, 2) == (off_t) NOTOK) {
+		if (lseek (fd, (off_t) 0, SEEK_END) == (off_t) NOTOK) {
 		    close (fd);
 		    return NOTOK;
 		}
@@ -150,7 +150,7 @@ mbx_chk (int fd)
 
     count = strlen (mmdlm2);
 
-    if (lseek (fd, (off_t) (-count), 2) == (off_t) NOTOK
+    if (lseek (fd, (off_t) (-count), SEEK_END) == (off_t) NOTOK
 	    || read (fd, ldelim, count) != count)
 	return NOTOK;
     ldelim[count] = 0;
@@ -246,11 +246,11 @@ mbx_write(char *mailbox, int md, FILE *fp, int id, long last,
     register char *cp;
     char buffer[BUFSIZ];
 
-    off = (long) lseek (md, (off_t) 0, 1);
+    off = (long) lseek (md, (off_t) 0, SEEK_CUR);
     j = strlen (mmdlm1);
     if (write (md, mmdlm1, j) != j)
 	return NOTOK;
-    start = lseek (md, (off_t) 0, 1);
+    start = lseek (md, (off_t) 0, SEEK_CUR);
     size = 0;
 
     fseek (fp, pos, 0);
@@ -269,7 +269,7 @@ mbx_write(char *mailbox, int md, FILE *fp, int id, long last,
 		    size++;
     }
 
-    stop = lseek (md, (off_t) 0, 1);
+    stop = lseek (md, (off_t) 0, SEEK_CUR);
     j = strlen (mmdlm2);
     if (write (md, mmdlm2, j) != j)
 	return NOTOK;
@@ -290,7 +290,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
     char buffer[BUFSIZ];
     register FILE *fp;
 
-    pos = (long) lseek (md, (off_t) 0, 1);
+    pos = (long) lseek (md, (off_t) 0, SEEK_CUR);
     size = 0;
 
     switch (mbx_style) {
@@ -299,7 +299,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 	    j = strlen (mmdlm1);
 	    if (write (md, mmdlm1, j) != j)
 		return NOTOK;
-	    start = lseek (md, (off_t) 0, 1);
+	    start = lseek (md, (off_t) 0, SEEK_CUR);
 
 	    if (text) {
 		i = strlen (text);
@@ -327,7 +327,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 			    size++;
 	    }
 
-	    stop = lseek (md, (off_t) 0, 1);
+	    stop = lseek (md, (off_t) 0, SEEK_CUR);
 	    j = strlen (mmdlm2);
 	    if (write (md, mmdlm2, j) != j)
 		return NOTOK;
@@ -343,7 +343,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 		close (j);
 		return NOTOK;
 	    }
-	    start = lseek (md, (off_t) 0, 1);
+	    start = lseek (md, (off_t) 0, SEEK_CUR);
 
 	    if (text) {
 		i = strlen (text);
@@ -376,8 +376,8 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 	    if (mapping) size += 2;
 
 	    fclose (fp);
-	    lseek (fd, (off_t) 0, 2);
-	    stop = lseek (md, (off_t)0, 1);
+	    lseek (fd, (off_t) 0, SEEK_END);
+	    stop = lseek (md, (off_t)0, SEEK_CUR);
 	    if (mapping)
 		map_write (mailbox, md, 0, (long)0, start, stop, pos, size, noisy);
 
@@ -465,7 +465,7 @@ map_read (char *file, long pos, struct drop **drops, int noisy)
 
     memcpy((char *) dp, (char *) mp, sizeof *dp);
 
-    lseek (md, (off_t) sizeof *mp, 0);
+    lseek (md, (off_t) sizeof(*mp), SEEK_SET);
     if ((i = read (md, (char *) (dp + 1), msgp * sizeof *dp)) < sizeof *dp) {
 	i = 0;
 	free ((char *) dp);
@@ -537,7 +537,7 @@ map_write (char *mailbox, int md, int id, long last, off_t start,
 		for (dp = rp; i-- >0; dp++) {
 		    if (dp->d_start == start)
 			dp->d_id = id;
-		    lseek (fd, (off_t) (++d1.d_id * sizeof *dp), 0);
+		    lseek (fd, (off_t) (++d1.d_id * sizeof(*dp)), SEEK_SET);
 		    if (write (fd, (char *) dp, sizeof *dp) != sizeof *dp) {
 			if (noisy)
 			    admonish (file, "write error");
@@ -558,7 +558,7 @@ map_write (char *mailbox, int md, int id, long last, off_t start,
 	dp->d_size = (long) (size ? size : mbx_size (fd, start, stop));
 	dp->d_start = start;
 	dp->d_stop = stop;
-	lseek (fd, (off_t) (++d1.d_id * sizeof *dp), 0);
+	lseek (fd, (off_t) (++d1.d_id * sizeof(*dp)), SEEK_SET);
 	if (write (fd, (char *) dp, sizeof *dp) != sizeof *dp) {
 	    if (noisy)
 		admonish (file, "write error");
@@ -570,9 +570,9 @@ map_write (char *mailbox, int md, int id, long last, off_t start,
     dp = &d1;
     dp->d_size = DRVRSN;
     dp->d_start = (long) last;
-    dp->d_stop = lseek (md, (off_t)0, 1);
+    dp->d_stop = lseek (md, (off_t) 0, SEEK_CUR);
 
-    lseek (fd, (off_t) 0, 0);
+    lseek (fd, (off_t) 0, SEEK_SET);
     if (write (fd, (char *) dp, sizeof *dp) != sizeof *dp) {
 	if (noisy)
 	    admonish (file, "write error");
@@ -634,7 +634,7 @@ map_chk (char *file, int fd, struct drop *dp, long pos, int noisy)
 	return NOTOK;
     }
 
-    if ((long) ((dp->d_id + 1) * sizeof *dp) != (long) lseek (fd, (off_t) 0, 2)) {
+    if ((long) ((dp->d_id + 1) * sizeof(*dp)) != (long) lseek (fd, (off_t) 0, SEEK_END)) {
 	if (noisy)
 	    admonish (NULL, "%s: corrupt index(1)", file);
 	return NOTOK;
@@ -642,7 +642,7 @@ map_chk (char *file, int fd, struct drop *dp, long pos, int noisy)
 
     dl = &d;
     count = (long) strlen (mmdlm2);
-    lseek (fd, (off_t) (dp->d_id * sizeof *dp), 0);
+    lseek (fd, (off_t) (dp->d_id * sizeof(*dp)), SEEK_SET);
     if (read (fd, (char *) dl, sizeof *dl) != sizeof *dl
 	    || (ntohl(dl->d_stop) != dp->d_stop
 		&& ntohl(dl->d_stop) + count != dp->d_stop)) {
