@@ -1,5 +1,5 @@
 /*
- * flist.c -- list mh folders with unseen messages
+ * flist.c -- list nmh folders containg messages in a given sequence
  *
  * originally by
  * David Nichols, Xerox-PARC, November, 1992
@@ -15,57 +15,61 @@
  *  $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #define FALSE   0
 #define TRUE    1
 
 static struct swit switches[] = {
-#define ALPHASW         0
-    { "alpha", 0 },
-#define NOALPHASW       1
-    { "noalpha", 0 },
-#define TOTAL           2
-    { "total", 0 },
-#define NOTOTAL         3
-    { "nototal", 0 },
-#define RECURSE         4
-    { "recurse", 0 },
-#define NORECURSE       5
-    { "norecurse", 0 },
-#define ALLSW           6
+#define SEQSW           0
+    { "sequence name", 0 },
+#define ALLSW           1
     { "all", 0 },
-#define UNSEENSW        7
-    { "unseen", 0 },
-#define VERSIONSW	8
+#define NOALLSW         2
+    { "noall", 0 },
+#define ALPHASW         3
+    { "alpha", 0 },
+#define NOALPHASW       4
+    { "noalpha", 0 },
+#define TOTAL           5
+    { "total", 0 },
+#define NOTOTAL         6
+    { "nototal", 0 },
+#define RECURSE         7
+    { "recurse", 0 },
+#define NORECURSE       8
+    { "norecurse", 0 },
+#define VERSIONSW	9
     { "version", 0 },
-#define HELPSW          9
+#define HELPSW          10
     { "help", 4 },
     { NULL, NULL }
 };
 
 struct Folder {
-    char *name;
+    char *name;		/* name of folder */
     int priority;
-    int nMsgs;
-    int nUnseen;
+    int nMsgs;		/* number of messages in folder         */
+    int nSeq;		/* number of messages in given sequence */
 };
 
-struct Folder *orders = NULL;
-int nOrders = 0;
-int nOrdersAlloced = 0;
-struct Folder *folders = NULL;
-int nFolders = 0;
-int nFoldersAlloced = 0;
+static struct Folder *orders = NULL;
+static int nOrders = 0;
+static int nOrdersAlloced = 0;
+static struct Folder *folders = NULL;
+static int nFolders = 0;
+static int nFoldersAlloced = 0;
 
-char **foldersToDo;
-int nFoldersToDo;
+static char **foldersToDo;
+static int nFoldersToDo;
 
-int allFolders = FALSE;		/* show all folders or just with unseen msgs? */
-int alphaOrder = FALSE;		/* want alphabetical order only */
-int noTotal = FALSE;		/* display the folder name only? */
-int recurse = FALSE;		/* show nested folders? */
-char *unseenSequence;
+static int allFolders = FALSE;	/* show all folders or just with given seq? */
+static int alphaOrder = FALSE;	/* want alphabetical order only             */
+static int recurse    = FALSE;	/* show nested folders?                     */
+static int Total      = TRUE;	/* display info on number of messages in    *
+				 * sequence found, and total num messages   */
+
+static char *sequence;		/* name of sequence we are searching for    */
 
 /*
  * Type for a compare function for qsort.  This keeps
@@ -78,9 +82,9 @@ typedef int (*qsort_comp) (const void *, const void *);
  */
 int CompareFolders(struct Folder *, struct Folder *);
 void GetFolderOrder(void);
-void BuildFolderList(void);
+void ScanMailDir(void);
 void AddFolder(char *, int);
-void BuildFolderListR(char *);
+void BuildFolderList(char *);
 void PrintFolders(void);
 void AllocFolders(struct Folder **, int *, int);
 
@@ -106,7 +110,7 @@ main(int argc, char **argv)
     foldersToDo = (char **) malloc(argc * sizeof(char *));
     nFoldersToDo = 0;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-') {
 	    switch (smatch(++cp, switches)) {
 	    case AMBIGSW:
@@ -116,17 +120,22 @@ main(int argc, char **argv)
 		adios(NULL, "-%s unknown", cp);
 
 	    case HELPSW:
-		sprintf(buf, "%s [switches]", invo_name);
+		sprintf(buf, "%s [+folder1 [+folder2 ...]][switches]", invo_name);
 		print_help(buf, switches);
 		done(1);
 	    case VERSIONSW:
 		print_version(invo_name);
 		done (1);
 
+	    case SEQSW:
+		if (!(cp = *argp++) || *cp == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		sequence = cp;
+		break;
 	    case ALLSW:
 		allFolders = TRUE;
 		break;
-	    case UNSEENSW:
+	    case NOALLSW:
 		allFolders = FALSE;
 		break;
 	    case ALPHASW:
@@ -136,10 +145,10 @@ main(int argc, char **argv)
 		alphaOrder = FALSE;
 		break;
 	    case TOTAL:
-		noTotal = FALSE;
+		Total = TRUE;
 		break;
 	    case NOTOTAL:
-		noTotal = TRUE;
+		Total = FALSE;
 		break;
 	    case RECURSE:
 		recurse = TRUE;
@@ -155,28 +164,32 @@ main(int argc, char **argv)
 	}
     }
 
-    unseenSequence = m_find("Unseen-Sequence");
+    /*
+     * If we didn't specify a sequence, we search
+     * for the `unseen' sequence.
+     */
+    if (!sequence)
+	sequence = m_find("Unseen-Sequence");
 
     GetFolderOrder();
-    BuildFolderList();
+    ScanMailDir();
     qsort(folders, nFolders, sizeof(struct Folder), (qsort_comp) CompareFolders);
     PrintFolders();
 }
 
 /*
- * Read the folder-order profile entry to determine how
- * to sort folders for output.
+ * Read the Flist-Order profile entry to determine
+ * how to sort folders for output.
  */
 
 void
 GetFolderOrder(void)
 {
-    char *p = m_find("Folder-order");
-    char *s;
+    char *p, *s;
     int priority = 1;
     struct Folder *o;
 
-    if (p == NULL)
+    if (!(p = m_find("Flist-Order")))
 	return;
     for (;;) {
 	while (isspace(*p))
@@ -198,62 +211,77 @@ GetFolderOrder(void)
 }
 
 /*
- * Build our list of folders.
+ * Scan the given list of folders, or the top
+ * level of our Mail directory.
  */
 
 void
-BuildFolderList(void)
+ScanMailDir(void)
 {
+    int i;
+    char *home, *path;
     DIR *dir;
     struct dirent *dp;
-    struct stat s;
-    char *home, *path;
-    int i;
-    int temp;
 
-    /* Did we specify which folders to check? */
+    /*
+     * Did we specify which folders to check?
+     */
     if (nFoldersToDo > 0) {
 	for (i = 0; i < nFoldersToDo; ++i)
-	    BuildFolderListR(m_mailpath(foldersToDo[i]));
+	    BuildFolderList(foldersToDo[i]);
 	return;
     }
 
-    /* Else do them all (at top level, at least) */
-
+    /*
+     * Else, scan the top level of the Mail directory
+     */
     if (!(home = getenv("HOME")) || (chdir(home) < 0))
 	adios(NULL, "Can't change to home directory.");
     if (!(path = m_find("path")))
 	adios(NULL, "Can't find Mail directory.");
-
     if (!(dir = opendir(path)))
 	adios(NULL, "Can't open Path");
 
     while ((dp = readdir(dir))) {
 	if (dp->d_name[0] == '.')
 	    continue;
-	temp = stat(dp->d_name, &s);
-        printf("stat of %s is %d\n", dp->d_name, temp);
-	/*     S_ISDIR(s.st_mode))
-	BuildFolderListR(dp->d_name); */
+	BuildFolderList(dp->d_name);
     }
 }
 
+/*
+ * Build list of folders
+ */
+
 void
-BuildFolderListR(char *dirName)
+BuildFolderList(char *dirName)
 {
     DIR *dir;
     struct dirent *dp;
     struct stat s;
-    char name[MAXPATHLEN];
+    char name[PATH_MAX];
 
-    printf("adding folder %s\n", dirName);
-    AddFolder(dirName, allFolders);
-
-    if (!recurse)
+    if (stat(m_mailpath(dirName), &s) == -1)
 	return;
 
-    if (!(dir = opendir(dirName)))
-	adios(NULL, "Can't scan mail dir.");
+    /*
+     * If we have a directory, then add it to
+     * our list of folders, else we return.
+     */
+    if (S_ISDIR(s.st_mode))
+	AddFolder(dirName, allFolders);
+    else
+	return;
+
+    /*
+     * If we are not recursing, or directory has no
+     * subdirectories, then we can return.
+     */
+    if (!recurse || s.st_nlink == 2)
+	return;
+
+    if (!(dir = opendir(m_mailpath(dirName))))
+	adios(NULL, "Error while scanning Mail directory");
 
     while ((dp = readdir(dir))) {
 	if (dp->d_name[0] == '.')
@@ -262,63 +290,70 @@ BuildFolderListR(char *dirName)
 	if (*dirName)
 	    strcat(name, "/");
 	strcat(name, dp->d_name);
-	if ((stat(name, &s) != -1) && ((s.st_mode & S_IFMT) == S_IFDIR))
-		BuildFolderListR(name);
+	BuildFolderList(name);
     }
     closedir(dir);
 }
 
 /*
- * Add this folder to our list,
- * counting the messages (seen and unseen).
+ * Add this folder to our list, counting the
+ * number of messages in given sequence and
+ * total number of messages.
  */
 
 void
 AddFolder(char *name, int force)
 {
-    struct msgs *mp;
-    int nUnseen;
-    int i;
-    struct Folder *f;
-    int flags;
     char buf[1024];
+    int i, flags, nSeq;
     struct stat s;
+    struct Folder *f;
+    struct msgs *mp;
 
-    /* Attempt to avoid reading this directory if we're */
-    /* only looking for unseen messages.                */
+#if 0
+    /*
+     * Attempt a shortcut to avoid reading this directory
+     * if we're only looking for unseen messages, by
+     * checking if a sequence file exists in this folder.
+     */
     if (!force) {
 	sprintf(buf, "%s/%s", name, mh_seq);
 	if (stat(buf, &s) < 0)
 	    return;
     }
+#endif
 
-    mp = m_gmsg(name);
-    nUnseen = 0;
-    if (mp == NULL) {
+    nSeq = 0;
+    if (!(mp = m_gmsg(name))) {
 	advise(NULL, "Can't read folder %s.", name);
 	return;
     }
 
-    if (unseenSequence)
-	flags = m_seqflag(mp, unseenSequence);
+    /*
+     * Get the bit flag corresponding to the
+     * sequence we want to search for.
+     */
+    if (sequence)
+	flags = m_seqflag(mp, sequence);
     else
 	flags = 0;
 
     if (flags) {
-	for (i = mp->lowmsg; i <= mp->hghmsg; ++i) {
+	for (i = mp->lowmsg; i <= mp->hghmsg; i++) {
 	    if (mp->msgstats[i] & flags)
-		++nUnseen;
+		nSeq++;
 	}
     }
 
-    /* Save it. */
-    if (nUnseen > 0 || force) {
+    /*
+     * Save information in Folder struct.
+     */
+    if (nSeq > 0 || force) {
 	AllocFolders(&folders, &nFoldersAlloced, nFolders + 1);
 	f = &folders[nFolders++];
-	f->name = (char *) malloc(strlen(name) + 1);
-	strcpy(f->name, name);
+	f->name = getcpy(name);
 	f->nMsgs = mp->nummsg;
-	f->nUnseen = nUnseen;
+	f->nSeq = nSeq;
 	f->priority = AssignPriority(f->name);
     }
 }
@@ -329,11 +364,11 @@ PrintFolders(void)
     int i;
 
     for (i = 0; i < nFolders; ++i) {
-	if (noTotal) {
-	    printf("%s\n", folders[i].name);
+	if (Total) {
+	    printf("+%-12s %3d in sequence %s, out of %3d\n", folders[i].name,
+		   folders[i].nSeq, sequence, folders[i].nMsgs);
 	} else {
-	    printf("  +%-20s %4d new out of %4d\n", folders[i].name,
-		   folders[i].nUnseen, folders[i].nMsgs);
+	    printf("%s\n", folders[i].name);
 	}
     }
 }
@@ -376,24 +411,22 @@ AllocFolders(struct Folder **f, int *nfa, int n)
 int
 AssignPriority(char *name)
 {
-    int i;
-    struct Folder *o;
-    int nl = strlen(name);
-    int ol;
+    int i, ol, nl;
     int best = nOrders;
     int bestLen = 0;
+    struct Folder *o;
 
+    nl = strlen(name);
     for (i = 0; i < nOrders; ++i) {
 	o = &orders[i];
-	if (strcmp(name, o->name) == 0)
+	if (!strcmp(name, o->name))
 	    return o->priority;
 	ol = strlen(o->name);
 	if (nl < ol - 1)
 	    continue;
 	if (ol < bestLen)
 	    continue;
-	if (o->name[0] == '*'
-		&& strcmp(o->name + 1, name + (nl - ol + 1)) == 0) {
+	if (o->name[0] == '*' && !strcmp(o->name + 1, name + (nl - ol + 1))) {
 	    best = o->priority;
 	    bestLen = ol;
 	} else if (o->name[ol - 1] == '*' && strncmp(o->name, name, ol - 1) == 0) {
