@@ -72,7 +72,7 @@ static int getreply (int, int);
 static int
 start_tcp_server (struct sockaddr_in *sock, int backlog, int opt1, int opt2)
 {
-    int	eindex, sd;
+    int eindex, sd;
 
     if ((sd = socket (AF_INET, SOCK_STREAM, 0)) == NOTOK)
 	return NOTOK;
@@ -268,7 +268,7 @@ bad: ;
 
     istore = !strcmp (cmd, "STOR");
 
-    if (istdio = !strcmp (local, "-"))
+    if ((istdio = !strcmp (local, "-")))
 	fp = istore ? stdin : stdout;
     else
 	if ((fp = fopen (local, istore ? "r" : "w")) == NULL) {
