@@ -39,7 +39,7 @@ main (int argc, char **argv)
 
     autof = (argc == 2 && strcmp (argv[1], "-auto") == 0);
     if (mypath == NULL) {	/* straight from m_getdefs... */
-	if (mypath = getenv ("HOME"))
+	if ((mypath = getenv ("HOME")))
 	    mypath = getcpy (mypath);
 	else
 	    if ((pw = getpwuid (getuid ())) == NULL
@@ -122,7 +122,7 @@ main (int argc, char **argv)
     np->n_context = 0;
     np->n_next = NULL;
 
-    if (in = fopen (mh_defaults, "r")) {
+    if ((in = fopen (mh_defaults, "r"))) {
 	m_readefs (&np->n_next, in, mh_defaults, 0);
 	fclose (in);
     }
@@ -151,7 +151,7 @@ geta (void)
     fflush(stdout);
     if (fgets(line, sizeof line, stdin) == NULL)
 	done (1);
-    if (cp = strchr(line, '\n'))
+    if ((cp = strchr(line, '\n')))
 	*cp = 0;
     return line;
 }
