@@ -1454,8 +1454,6 @@ face_format (struct mcomp *c1)
 }
 
 
-#ifdef SOCKETS
-
 /*
  * faceproc is two elements defining the image agent's location:
  *     Internet host
@@ -1470,7 +1468,6 @@ face_format (struct mcomp *c1)
 # include <arpa/inet.h>
 #endif
 
-
 static int
 doface (struct mcomp *c1)
 {
@@ -1521,7 +1518,11 @@ bad_faceproc: ;
     return (result != NOTOK ? OK : NOTOK);
 }
 
-#else /* not SOCKETS */
+/*
+ * COMMENTED OUT
+ * This version doesn't use sockets
+ */
+#if 0
 
 static int
 doface (struct mcomp *c1)
@@ -1627,7 +1628,7 @@ doface (struct mcomp *c1)
 
     return result;
 }
-#endif /* not SOCKETS */
+#endif /* COMMENTED OUT */
 
 
 int
