@@ -115,7 +115,7 @@ main (int argc, char **argv)
 	adios (tmpfil, "unable to write");
     chmod (tmpfil, 0600);
 
-    setsig (SIGINT, intrser);
+    SIGNAL2 (SIGINT, intrser);
 
     fprintf (out, "%sTo: %s\n", resent ? "Resent-" : "", tolist);
     if (cclist)
@@ -184,11 +184,12 @@ main (int argc, char **argv)
 static RETSIGTYPE
 intrser (int i)
 {
-#ifndef	BSD42
+#ifndef RELIABLE_SIGNALS
     if (i)
-	signal (i, SIG_IGN);
-#endif	/* BSD42 */
+	SIGNAL (i, SIG_IGN);
+#endif
 
     unlink (tmpfil);
     done (i != 0 ? 1 : 0);
 }
+
