@@ -20,6 +20,7 @@
 #endif
 
 #include <h/popsbr.h>
+#include <h/signals.h>
 #include <signal.h>
 
 #define	TRM	"."
@@ -160,7 +161,7 @@ pop_init (char *host, char *user, char *pass, int snoop)
 #endif	/* NNTP */
 	return NOTOK;
 
-    signal (SIGPIPE, SIG_IGN);
+    SIGNAL (SIGPIPE, SIG_IGN);
 
     switch (getline (response, sizeof response, input)) {
 	case OK: 
