@@ -1797,7 +1797,7 @@ do_text (char *file, int fd)
     struct rp_bufstruct reply;
 #endif	/* MMDFMTS */
 
-    lseek (fd, (off_t) 0, 0);
+    lseek (fd, (off_t) 0, SEEK_SET);
     while ((state = read (fd, buf, sizeof buf)) > 0)
 #ifdef	MMDFMTS
 	if (rp_isbad (mm_wtxt (buf, state)))
@@ -2376,7 +2376,7 @@ localmail (struct mailname *lp, int talk, int fd)
 	    fflush (stdout);
 
 	case NOTOK: 
-	    lseek (fd, (off_t) 0, 0);
+	    lseek (fd, (off_t) 0, SEEK_SET);
 	    if ((md = mbx_open (mailbox, hp->h_uid, hp->h_gid, m_gmprot ()))
 		    == NOTOK) {
 		if (!talk)
@@ -2449,9 +2449,9 @@ usr_hook (struct mailname *lp, int talk, int fd, struct home *hp, char *mailbox)
 		close (fd);
 	    }
 #endif	/* TIOCNOTTY */
-#ifdef	BSD42
+#ifdef BSD42
 	    setpgrp (0, getpid ());
-#endif	/* BSD42 */
+#endif /* BSD42 */
 
 	    *environ = NULL;
 	    m_putenv ("USER", hp->h_name);
@@ -2460,13 +2460,10 @@ usr_hook (struct mailname *lp, int talk, int fd, struct home *hp, char *mailbox)
 	    if (chdir (hp->h_home) == NOTOK)
 		chdir ("/");
 	    umask (0077);
-#ifdef	BSD41A
-	    inigrp (hp->h_name, hp->h_gid);
-#endif	/* BSD41A */
 	    setgid (hp->h_gid);
-#ifdef	BSD42
+#ifdef BSD42
 	    initgroups (hp->h_name, hp->h_gid);
-#endif	/* BSD42 */
+#endif /* BSD42 */
 	    setuid (hp->h_uid);
 
 	    execlp (slocalproc, r1bindex (slocalproc, '/'),
@@ -2509,7 +2506,7 @@ copyfile (int qd, char *tmpfil)
     if ((fd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	return NOTOK;
 
-    lseek (qd, (off_t) 0, 0);
+    lseek (qd, (off_t) 0, SEEK_SET);
     while ((i = read (qd, buffer, sizeof buffer)) > 0)
 	if (write (fd, buffer, i) != i) {
 	    close (fd);
@@ -2520,7 +2517,7 @@ copyfile (int qd, char *tmpfil)
 	return NOTOK;
     }
 
-    lseek (fd, (off_t) 0, 0);
+    lseek (fd, (off_t) 0, SEEK_SET);
 
     return fd;
 }
@@ -2564,7 +2561,7 @@ uucpmail (struct mailname *lp, int talk, int fd, int from)
 	    goto oops;
     }
 
-    lseek (fd, (off_t) 0, 0);
+    lseek (fd, (off_t) 0, SEEK_SET);
     while ((i = read (fd, buffer, sizeof buffer)) > 0)
 	if (fwrite (buffer, sizeof *buffer, i, fp) != i) {
     oops:   ;
@@ -2601,7 +2598,7 @@ make_uucp_file (int td)
     int i, qd, fd;
     char tmpfil[BUFSIZ];
 
-    lseek (td, (off_t) 0, 0);
+    lseek (td, (off_t) 0, SEEK_SET);
     if ((qd = dup (td)) == NOTOK)
 	adios ("fd", "unable to dup");
 
@@ -2652,7 +2649,7 @@ netmail (int talk, int fd, int bccque)
 	}
     nm_waend ();
 
-    lseek (fd, (off_t) 0, 0);
+    lseek (fd, (off_t) 0, SEEK_SET);
     while ((i = read (fd, buffer, sizeof buffer)) > 0)
 	if (nm_wtxt (buffer, i) == NOTOK) {
 	    fprintf (stderr,
