@@ -281,7 +281,7 @@ alert (char *tty, int md)
 	return;
     }
 
-    lseek (md, (off_t) 0, 0);
+    lseek (md, (off_t) 0, SEEK_SET);
 
     while ((i = read (md, buffer, sizeof buffer)) > 0)
 	if (write (td, buffer, i) != i)
@@ -302,7 +302,7 @@ alert (char *user, int md)
 	return;
     SIGNAL (SIGPIPE, SIG_IGN);
 
-    lseek (md, (off_t), 0);
+    lseek (md, (off_t), SEEK_SET);
     while ((i = read (md, buffer, sizeof buffer)) > 0)
 	if (write (td, buffer, i) != i)
 	    break;
