@@ -406,7 +406,7 @@ replfilter (FILE *in, FILE *out)
     mhl = r1bindex (mhlproc, '/');
 
     rewind (in);
-    lseek (fileno(in), (off_t)0, L_SET);
+    lseek (fileno(in), (off_t)0, SEEK_SET);
     fflush (out);
 
     switch (pid = vfork ()) {
