@@ -5,14 +5,14 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 static struct swit switches[] = {
-#define VERSIONSW 0
-    "version", 0,
-#define	HELPSW	1
-    "help", 4,
-    NULL, 0
+#define VERSIONSW   0
+    { "version", 0 },
+#define	HELPSW      1
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 
@@ -37,7 +37,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
