@@ -216,7 +216,8 @@ main (int argc, char **argv)
     m_sync (mp);
     m_update ();
 
-    if (cp = m_find(usequence)) { /* set bits for each unseen sequence */
+    if ((cp = m_find(usequence))) {
+	/* set bits for each unseen sequence */
 	char *dp = NULL;
 
 	bits = 0;
