@@ -508,8 +508,7 @@ rename_chain (struct msgs *mp, struct smsg **mlist, int msg, int endmsg)
 static void
 rename_msgs (struct msgs *mp, struct smsg **mlist)
 {
-    int i, j, old, new;
-    short stats;
+    int i, j, old, new, stats;
     char f1[BUFSIZ], tmpfil[BUFSIZ];
     struct smsg *sp;
 
