@@ -154,7 +154,7 @@ localmail (int fd)
 
     for (i = 0; bp = bb[i]; i++)
 	if (bp->bb_file && *bp->bb_file) {
-	    lseek (fd, (off_t)0, 0);
+	    lseek (fd, (off_t)0, SEEK_SET);
 #ifndef	SPOP
 	    if ((md = mbx_open (bp->bb_file, bb_uid, bb_gid, BBMODE))
 #else	SPOP
@@ -287,7 +287,7 @@ dst_text (int fd)
     if (rp_isbad (retval = sm_waend ()))
 	return lose ("problem ending addresses; %s", rp_string (retval));
 
-    lseek (fd, (off_t)0, 0);
+    lseek (fd, (off_t)0, SEEK_SET);
     while ((i = read (fd, buffer, sizeof buffer)) > 0)
 	if (rp_isbad (retval = sm_wtxt (buffer, i)))
 	    return lose ("problem writing text; %s", rp_string (retval));
@@ -391,7 +391,7 @@ notify (int fd)
 	    goto sm_err;
     }
 
-    lseek (bb_fderr, (off_t)0, 0);
+    lseek (bb_fderr, (off_t)0, SEEK_SET);
     while ((i = read (bb_fderr, buffer, sizeof buffer)) > 0)
 	if (rp_isbad (sm_wtxt (buffer, i)))
 	    goto sm_err;
@@ -440,7 +440,7 @@ encap (int fd)
     register char *bp, *dp;
     char outbuf[BUFSIZ];
 
-    lseek (fd, (off_t)0, 0);
+    lseek (fd, (off_t)0, SEEK_SET);
 
     dp = (bp = outbuf) + sizeof outbuf;
     for (state = S1; (i = read (fd, buffer, sizeof buffer)) > 0;)
@@ -563,14 +563,14 @@ copyfile (int qd, char *tmpfil)
     if ((fd = open (tmpfil, 2)) == NOTOK)
 	adios (EX_NOINPUT, tmpfil, "unable to re-open");
 
-    lseek (qd, (off_t)0, 0);
+    lseek (qd, (off_t)0, SEEK_SET);
     while ((i = read (qd, buffer, sizeof buffer)) > 0)
 	if (write (fd, buffer, i) != i)
 	    adios (EX_IOERR, tmpfil, "error writing");
     if (i == NOTOK)
 	adios (EX_IOERR, "input", "error reading");
 
-    lseek (fd, (off_t)0, 0);
+    lseek (fd, (off_t)0, SEEK_SET);
 
     return fd;
 }
