@@ -5,45 +5,38 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/vmhsbr.h"
+#include <h/mh.h>
+#include <h/vmhsbr.h>
 
 static struct swit switches[] = {
-#define	READSW	0
-    "vmhread fd", 7,	
-#define	WRITESW	1
-    "vmhwrite fd", 8,	
-#define VERSIONSW 2
-    "version", 0,
-#define	HELPSW	3
-    "help", 4,		
-    NULL, NULL
+#define	READSW          0
+    { "vmhread fd", 7 },	
+#define	WRITESW         1
+    { "vmhwrite fd", 8 },	
+#define VERSIONSW       2
+    { "version", 0 },
+#define	HELPSW          3
+    { "help", 4 },
+    { NULL, NULL }
 };
 
-#define	NWIN	20
-static	int	numwins = 0;
-static	int	windows[NWIN + 1];
+#define	NWIN 20
+static int numwins = 0;
+static int windows[NWIN + 1];
 
 
-static	int	selcmds = 0;
+static int selcmds = 0;
 #define	selcmd()	(selcmds++ % 2)
 
-static	int	selwins = 0;
+static int selwins = 0;
 #define	selwin()	(selwins++ % 2 ? 3 : 1)
 
 
-main (argc, argv, envp)
-int     argc;
-char  **argv,
-      **envp;
+main (int argc, char **argv)
 {
-    int     fd1,
-            fd2;
-    char   *cp,
-            buffer[BUFSIZ],
-          **ap,
-          **argp = argv + 1,
-           *arguments[MAXARGS];
+    int fd1, fd2;
+    char *cp, buffer[BUFSIZ], **ap;
+    char **argp = argv + 1, *arguments[MAXARGS];
 
 #ifdef LOCALE
 	setlocale(LC_ALL, "");
@@ -51,7 +44,7 @@ char  **argv,
     invo_name = r1bindex (argv[0], '/');
     m_foil (NULL);
 
-    while (cp = *argp++)
+    while ((cp = *argp++))
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
