@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <h/signals.h>
 #include <signal.h>
 
 static struct swit switches[] = {
@@ -167,10 +168,10 @@ main (int argc, char **argv)
 	    _exit (-1);
 
 	default:
-	    signal (SIGHUP, SIG_IGN);
-	    signal (SIGINT, SIG_IGN);
-	    signal (SIGQUIT, SIG_IGN);
-	    signal (SIGTERM, SIG_IGN);
+	    SIGNAL (SIGHUP, SIG_IGN);
+	    SIGNAL (SIGINT, SIG_IGN);
+	    SIGNAL (SIGQUIT, SIG_IGN);
+	    SIGNAL (SIGTERM, SIG_IGN);
 
 	    status = pidwait(child_id, OK);
 
