@@ -7,11 +7,6 @@
 
 #include <h/mh.h>
 
-/*
- * ENCLOSES REST OF THE FILE
- */
-#ifdef SOCKETS
-
 #if defined(SYS5) && defined(AUX)
 # define u_short ushort
 # define u_long  ulong
@@ -456,4 +451,4 @@ client_getcpy (char *str)
     memcpy (cp, str, len);
     return cp;
 }
-#endif	/* SOCKETS */
+
