@@ -258,11 +258,7 @@ f_lkopen (char *file, int access)
 	if (lockf (fd, F_TLOCK, 0L) != NOTOK) {
 	    /* see if we should be at the end */
 	    if (j & O_APPEND)
-#  ifdef SVR4
 		lseek (fd, (off_t) 0, SEEK_END);
-#  else
-		lseek (fd, (off_t) 0, L_XTND);
-#  endif
 	    return fd;
 	}
 	/* Fix errno - lockf screws it */
@@ -314,8 +310,8 @@ lkclose (int fd, char *file)
 	    flock (fd, LOCK_UN);
 	    break;
 # endif
-#else	/* LOCKF */
-	    lseek (fd, (off_t) 0, L_SET); /* make sure we unlock the whole thing */
+#else /* LOCKF */
+	    lseek (fd, (off_t) 0, SEEK_SET); /* make sure we unlock the whole thing */
 	    lockf (fd, F_ULOCK, 0L);
 	    break;
 #endif	
