@@ -9,31 +9,18 @@
 
 #define nmhetcdir(file) NMHETCDIR#file
 
-#undef NETWORK
-#if defined(BSD41A) || defined(BSD42) || defined(SOCKETS)
-# define NETWORK
-#endif
-
 #include <ctype.h>
 #include <stdio.h>
 #include <mts.h>
-
-#ifdef NETWORK
-# ifdef SOCKETS
-#  include <netdb.h>
-# endif
-#else	/* NETWORK */
-# ifndef SYS5
-#  include <whoami.h>
-# else
-#  include <sys/utsname.h>
-# endif /* SYS5 */
-#endif /* NETWORK */
-
 #include <pwd.h>
+#include <netdb.h>
 
-#define	NOTOK	(-1)
-#define	OK	0
+#ifdef HAVE_SYS_UTSNAME_H
+# include <sys/utsname.h>
+#endif
+
+#define	NOTOK   (-1)
+#define	OK        0
 
 extern int errno;
 
@@ -325,16 +312,12 @@ tailor_value (char *s)
 char *
 LocalName (void)
 {
-#ifdef BSD41A
-    char  *myname;
-#endif /* BSD41A */
-#if defined(BSD42) || defined(SOCKETS)
-    register struct hostent *hp;
-#endif /* BSD42 or SOCKETS */
-#if defined(SYS5) && !defined(NETWORK)
-    struct utsname name;
-#endif /* SYS5 and not NETWORK */
     static char buffer[BUFSIZ] = "";
+    struct hostent *hp;
+
+#ifdef HAVE_UNAME
+    struct utsname name;
+#endif
 
     if (buffer[0])
 	return buffer;
@@ -343,37 +326,20 @@ LocalName (void)
     if (*localname)
 	strcpy (buffer, localname);
     else {
-
-#ifdef locname
-    strcpy (buffer, locname);
-#else /* not locname */
-#ifdef NETWORK
-#ifdef BSD41A
-    myname = "myname";
-    if (rhost (&myname) == -1)
-	gethostname (buffer, sizeof(buffer));
-    else {
-	strcpy (buffer, myname);
-	free (myname);
-    }
-#endif /* BSD41A */
-#if defined(BSD42) || defined(SOCKETS)
-    gethostname (buffer, sizeof(buffer));
-#ifndef	BIND
-    sethostent (1);
-#endif
-    if ((hp = gethostbyname (buffer)))
-	strcpy (buffer, hp->h_name);
-#endif /* BSD42 or SOCKETS */
-#else /* not NETWORK */
-#ifndef	SYS5
-    strcpy (buffer, SystemName ());
-#else /* SYS5 */
+#ifdef HAVE_UNAME
+    /* first get our local name */
     uname (&name);
     strcpy (buffer, name.nodename);
-#endif /* SYS5 */
-#endif /* not NETWORK */
-#endif /* not locname */
+#else
+    /* first get our local name */
+    gethostname (buffer, sizeof(buffer));
+#endif
+#ifndef BIND
+    sethostent(1);
+#endif
+    /* now fully qualify our name */
+    if ((hp = gethostbyname (buffer)))
+	strcpy (buffer, hp->h_name);
     }
     if (*localdomain) {
 	strcat (buffer, ".");
@@ -385,30 +351,27 @@ LocalName (void)
 char *
 SystemName (void)
 {
-#if defined(SYS5) && !defined(NETWORK)
-    struct utsname name;
-#endif /* SYS5 and not NETWORK */
     static char buffer[BUFSIZ] = "";
 
+#ifdef HAVE_UNAME
+    struct utsname name;
+#endif
+
     if (buffer[0])
 	return buffer;
 
     mts_init ("mts");
-    if (*systemname)
-	return strcpy (buffer, systemname);
+    if (*systemname) {
+	strcpy (buffer, systemname);
+	return buffer;
+    }
 
-#ifdef sysname
-    strcpy (buffer, sysname);
-#else /* sysname */
-#if !defined(SYS5) || defined(NETWORK)
-    gethostname (buffer, sizeof(buffer));
-#else /* SYS5 and not NETWORK */
-#ifdef SYS5
+#ifdef HAVE_UNAME
     uname (&name);
     strcpy (buffer, name.nodename);
-#endif /* SYS5 */
-#endif /* SYS5 and not NETWORK */
-#endif /* sysname */
+#else
+    gethostname (buffer, sizeof(buffer));
+#endif
 
     return buffer;
 }
@@ -416,13 +379,13 @@ SystemName (void)
 char *
 UucpChan (void)
 {
-#ifdef	MF
+#ifdef MF
     static char buffer[BUFSIZ] = "";
-#endif /* MF */
+#endif
 
 #ifndef	MF
     return NULL;
-#else /* MF */
+#else
     if (buffer[0])
 	return buffer;
 
@@ -430,19 +393,19 @@ UucpChan (void)
     if (*UUCPchan)
 	return strcpy (buffer, UUCPchan);
 
-#ifdef	uucpchan
+#ifdef uucpchan
     strcpy (buffer, uucpchan);
 #else /* uucpchan */
     strcpy (buffer, "uucp");
 #endif /* uucpchan */
     return buffer;
-#endif /* MF */
+#endif
 }
 
+
 static char username[BUFSIZ];
 static char fullname[BUFSIZ];
 
-
 char *
 getusr (void)
 {
