@@ -8,9 +8,9 @@
 /*
  * Local and UUCP Host Name
  */
-char *LocalName();
-char *SystemName();
-char *UucpChan();
+char *LocalName(void);
+char *SystemName(void);
+char *UucpChan(void);
 
 /*
  * Mailboxes
@@ -25,9 +25,8 @@ extern char *uucplfil;
 #define	UUCPDIR	(uucpldir && *uucpldir ? uucpldir : getenv ("HOME"))
 #define	UUCPFIL	(uucplfil && *uucplfil ? uucplfil : getusr ())
 
-char *getusr();
-char *getfullname();
-char *getenv();
+char *getusr(void);
+char *getfullname(void);
 
 /*
  * Separators
@@ -64,7 +63,6 @@ int lkclose(int, char*);
 FILE *lkfopen(char *, char *);
 int lkfclose(FILE *, char *);
 
-
 /*
  * MTS specific variables
  */
@@ -90,7 +88,6 @@ extern char *hostable;
 extern char *sendmail;
 #endif /* SENDMTS */
 
-
 /*
  * SMTP/POP stuff
  */
@@ -98,13 +95,11 @@ extern char *clientname;
 extern char *servers;
 extern char *pophost;
 
-
 /*
  * BBoards-specific variables
  */
 extern char *bb_domain;
 
-
 /*
  * POP BBoards-specific variables
  */
@@ -114,13 +109,11 @@ extern char *popbbuser;
 extern char *popbblist;
 #endif /* BPOP */
 
-
 /*
  * MailDelivery
  */
 extern char *maildelivery;
 
-
 /*
  * Aliasing Facility (doesn't belong here)
  */
