@@ -74,7 +74,6 @@ char *tw_ldotw[] = {
     NULL
 };
 
-
 struct zone {
     char *std;
     char *dst;
@@ -287,22 +286,21 @@ dtimezone (int offset, int flags)
 	hours = offset / 60;
     }
 
-    if (!(flags & TW_ZONE) && mins == 0)
-#if	defined(SYS5) && defined(TZNAME)
-    {
+    if (!(flags & TW_ZONE) && mins == 0) {
+#if defined(SYS5) && defined(TZNAME)
 	tzset();
 	return ((flags & TW_DST) ? tzname[1] : tzname[0]);
-    }
 #else
 	for (z = zones; z->std; z++)
 	    if (z->shift == hours)
 		return (z->dst && (flags & TW_DST) ? z->dst : z->std);
 #endif
+    }
 
-#if	defined(DSTXXX)
+#if defined(DSTXXX)
     if (flags & TW_DST)
 	hours += 1;
-#endif	/* defined(DSTXXX) */
+#endif /* defined(DSTXXX) */
     sprintf (buffer, "%s%02d%02d", offset < 0 ? "-" : "+", abs (hours), abs (mins));
     return buffer;
 }
@@ -311,7 +309,7 @@ dtimezone (int offset, int flags)
 void
 twscopy (struct tws *tb, struct tws *tw)
 {
-#ifdef	notdef
+#if 0
     tb->tw_sec   = tw->tw_sec;
     tb->tw_min   = tw->tw_min;
     tb->tw_hour  = tw->tw_hour;
@@ -323,9 +321,9 @@ twscopy (struct tws *tb, struct tws *tw)
     tb->tw_zone  = tw->tw_zone;
     tb->tw_clock = tw->tw_clock;
     tb->tw_flags = tw->tw_flags;
-#else	/* not notdef */
-    *tb = *tw;
-#endif	/* not notdef */
+#else
+    *tb = *tw;  /* struct copy */
+#endif
 }
 
 
@@ -350,7 +348,7 @@ twsort (struct tws *tw1, struct tws *tw2)
  * Jay Lepreau at Utah-CS.
  */
 
-static int  dmsize[] = {
+static int dmsize[] = {
     31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
 };
 
@@ -394,9 +392,9 @@ twclock (struct tws *tw)
 
 
 /*
- *    Simple calculation of day of the week.  Algorithm used is Zeller's
- *    congruence.  Currently, we assume if tw->tw_year < 100
- *    then the century is CENTURY.
+ * Simple calculation of day of the week.  Algorithm used is Zeller's
+ * congruence.  Currently, we assume if tw->tw_year < 100
+ * then the century is CENTURY.
  */
 
 void
