@@ -1,7 +1,9 @@
 
-/* tws.h */
-
-/* $Id$ */
+/*
+ * tws.h
+ *
+ * $Id$
+ */
 
 #define	DSTXXX
 			/* DST vs. GMT nonsense */
@@ -10,19 +12,16 @@ struct tws {
     int tw_sec;
     int tw_min;
     int tw_hour;
-
     int tw_mday;
     int tw_mon;
     int tw_year;
-
     int tw_wday;
     int tw_yday;
-
     int tw_zone;
-
     long tw_clock;
+    int tw_flags;
+};
 
-    int     tw_flags;
 #define	TW_NULL	 0x0000
 #define	TW_SDAY	 0x0003	/* how day-of-week was determined */
 #define	TW_SNIL	 0x0000	/*   not given                    */
@@ -33,13 +32,6 @@ struct tws {
 #define	TW_SZEXP 0x0004	/*   explicitly given             */
 #define	TW_DST	 0x0010	/* daylight savings time          */
 #define	TW_ZONE	 0x0020	/* use numeric timezones only     */
-};
-
-void    twscopy ();
-int	twsort ();
-long	twclock ();
-char   *dasctime (), *dtimezone (), *dctime (), *dtimenow ();
-struct tws *dgmtime(), *dlocaltime (), *dparsetime (), *dtwstime ();
 
 #ifndef	ATZ
 # define dtime(cl) dasctime (dlocaltime (cl), TW_ZONE)
@@ -47,6 +39,26 @@ struct tws *dgmtime(), *dlocaltime (), *dparsetime (), *dtwstime ();
 # define dtime(cl) dasctime (dlocaltime (cl), TW_NULL)
 #endif
 
-#define	dtwszone(tw) dtimezone (tw -> tw_zone, tw -> tw_flags)
+#define	dtwszone(tw) dtimezone (tw->tw_zone, tw->tw_flags)
+
+extern char *tw_dotw[];
+extern char *tw_ldotw[];
+extern char *tw_moty[];
+
+/*
+ * prototypes
+ */
+char *dtimenow(void);
+char *dctime (struct tws *);
+struct tws *dtwstime (void);
+struct tws *dlocaltime (long *);
+struct tws *dgmtime (long *);
+char *dasctime (struct tws *, int);
+char *dtimezone (int, int);
+void twscopy (struct tws *, struct tws *);
+int twsort (struct tws *, struct tws *);
+long twclock (struct tws *);
+void set_dotw (struct tws *);
+
+struct tws *dparsetime (char *);
 
-extern char *tw_dotw[], *tw_ldotw[], *tw_moty[];
